@@ -22,9 +22,10 @@ GWEN_INHERIT(GWEN_WIDGET, W_SPINBOX)
 static GWENHYWFAR_CB
 int Gtk2Gui_WSpinBox_SetIntProperty(GWEN_WIDGET *w,
                                     GWEN_DIALOG_PROPERTY prop,
-                                    int index,
+                                    GWEN_UNUSED int index,
                                     int value,
-                                    int doSignal) {
+                                    GWEN_UNUSED int doSignal)
+{
   GtkWidget *g;
   W_SPINBOX *xw;
 
@@ -35,7 +36,7 @@ int Gtk2Gui_WSpinBox_SetIntProperty(GWEN_WIDGET *w,
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     gtk_widget_set_sensitive(GTK_WIDGET(g), (value==0)?FALSE:TRUE);
     return 0;
@@ -77,8 +78,9 @@ int Gtk2Gui_WSpinBox_SetIntProperty(GWEN_WIDGET *w,
 static GWENHYWFAR_CB
 int Gtk2Gui_WSpinBox_GetIntProperty(GWEN_WIDGET *w,
                                     GWEN_DIALOG_PROPERTY prop,
-                                    int index,
-                                    int defaultValue) {
+                                    GWEN_UNUSED int index,
+                                    int defaultValue)
+{
   GtkWidget *g;
   W_SPINBOX *xw;
 
@@ -89,7 +91,7 @@ int Gtk2Gui_WSpinBox_GetIntProperty(GWEN_WIDGET *w,
   g=GTK_WIDGET(GWEN_Widget_GetImplData(w, GTK2_DIALOG_WIDGET_REAL));
   assert(g);
 
-  switch(prop) {
+  switch (prop) {
   case GWEN_DialogProperty_Enabled:
     return (gtk_widget_get_sensitive(GTK_WIDGET(g))==TRUE)?1:0;
 
@@ -125,10 +127,11 @@ int Gtk2Gui_WSpinBox_GetIntProperty(GWEN_WIDGET *w,
 
 static GWENHYWFAR_CB
 int Gtk2Gui_WSpinBox_SetCharProperty(GWEN_WIDGET *w,
-                                     GWEN_DIALOG_PROPERTY prop,
-                                     int index,
-                                     const char *value,
-                                     int doSignal) {
+                                     GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                     GWEN_UNUSED int index,
+                                     GWEN_UNUSED const char *value,
+                                     GWEN_UNUSED int doSignal)
+{
   DBG_WARN(GWEN_LOGDOMAIN,
            "Function is not appropriate for this type of widget (%s)",
            GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
@@ -138,10 +141,11 @@ int Gtk2Gui_WSpinBox_SetCharProperty(GWEN_WIDGET *w,
 
 
 static GWENHYWFAR_CB
-const char* Gtk2Gui_WSpinBox_GetCharProperty(GWEN_WIDGET *w,
-    GWEN_DIALOG_PROPERTY prop,
-    int index,
-    const char *defaultValue) {
+const char *Gtk2Gui_WSpinBox_GetCharProperty(GWEN_WIDGET *w,
+                                             GWEN_UNUSED GWEN_DIALOG_PROPERTY prop,
+                                             GWEN_UNUSED int index,
+                                             const char *defaultValue)
+{
   DBG_WARN(GWEN_LOGDOMAIN,
            "Function is not appropriate for this type of widget (%s)",
            GWEN_Widget_Type_toString(GWEN_Widget_GetType(w)));
@@ -150,16 +154,18 @@ const char* Gtk2Gui_WSpinBox_GetCharProperty(GWEN_WIDGET *w,
 
 
 
-static void GWENHYWFAR_CB Gtk2Gui_WSpinBox_FreeData(void *bp, void *p) {
+static void GWENHYWFAR_CB Gtk2Gui_WSpinBox_FreeData(GWEN_UNUSED void *bp, void *p)
+{
   W_SPINBOX *xw;
 
-  xw=(W_SPINBOX*) p;
+  xw=(W_SPINBOX *) p;
   GWEN_FREE_OBJECT(xw);
 }
 
 
 
-static void Gtk2Gui_WSpinBox_Changed_handler(GtkAdjustment *adjustment, gpointer data) {
+static void Gtk2Gui_WSpinBox_Changed_handler(GWEN_UNUSED GtkAdjustment *adjustment, gpointer data)
+{
   GWEN_WIDGET *w;
   int rv;
 
@@ -176,35 +182,36 @@ static void Gtk2Gui_WSpinBox_Changed_handler(GtkAdjustment *adjustment, gpointer
 
 
 
-int Gtk2Gui_WSpinBox_Setup(GWEN_WIDGET *w) {
+int Gtk2Gui_WSpinBox_Setup(GWEN_WIDGET *w)
+{
   GtkWidget *g;
-  const char *s;
-  uint32_t flags;
+  /*const char *s;*/
+  /*uint32_t flags;*/
   GWEN_WIDGET *wParent;
   W_SPINBOX *xw;
-  gulong changed_handler_id;
+  /*gulong changed_handler_id;*/
 
   GWEN_NEW_OBJECT(W_SPINBOX, xw);
   GWEN_INHERIT_SETDATA(GWEN_WIDGET, W_SPINBOX, w, xw, Gtk2Gui_WSpinBox_FreeData);
 
-  flags=GWEN_Widget_GetFlags(w);
+  /*flags=GWEN_Widget_GetFlags(w);*/
   wParent=GWEN_Widget_Tree_GetParent(w);
-  s=GWEN_Widget_GetText(w, 0);
+  /*s=GWEN_Widget_GetText(w, 0);*/
 
   xw->adjustment=GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 100.0, 1.0, 5.0, 5.0));
   g=gtk_spin_button_new(xw->adjustment, 1.0, 0);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void*) g);
-  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void*) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_REAL, (void *) g);
+  GWEN_Widget_SetImplData(w, GTK2_DIALOG_WIDGET_CONTENT, (void *) g);
 
   GWEN_Widget_SetSetIntPropertyFn(w, Gtk2Gui_WSpinBox_SetIntProperty);
   GWEN_Widget_SetGetIntPropertyFn(w, Gtk2Gui_WSpinBox_GetIntProperty);
   GWEN_Widget_SetSetCharPropertyFn(w, Gtk2Gui_WSpinBox_SetCharProperty);
   GWEN_Widget_SetGetCharPropertyFn(w, Gtk2Gui_WSpinBox_GetCharProperty);
 
-  changed_handler_id=g_signal_connect(g,
-                                      "value-changed",
-                                      G_CALLBACK (Gtk2Gui_WSpinBox_Changed_handler),
-                                      w);
+  /*changed_handler_id=*/g_signal_connect(g,
+                                          "value-changed",
+                                          G_CALLBACK(Gtk2Gui_WSpinBox_Changed_handler),
+                                          w);
 
   if (wParent)
     GWEN_Widget_AddChildGuiWidget(wParent, w);
