@@ -49,7 +49,8 @@ GWEN_INHERIT(GWEN_SYNCIO, GWEN_SYNCIO_HTTP)
 
 
 
-GWEN_SYNCIO *GWEN_SyncIo_Http_new(GWEN_SYNCIO *baseIo) {
+GWEN_SYNCIO *GWEN_SyncIo_Http_new(GWEN_SYNCIO *baseIo)
+{
   GWEN_SYNCIO *sio;
   GWEN_SYNCIO_HTTP *xio;
 
@@ -76,10 +77,11 @@ GWEN_SYNCIO *GWEN_SyncIo_Http_new(GWEN_SYNCIO *baseIo) {
 
 
 
-void GWENHYWFAR_CB GWEN_SyncIo_Http_FreeData(void *bp, void *p) {
+void GWENHYWFAR_CB GWEN_SyncIo_Http_FreeData(GWEN_UNUSED void *bp, void *p)
+{
   GWEN_SYNCIO_HTTP *xio;
 
-  xio=(GWEN_SYNCIO_HTTP*) p;
+  xio=(GWEN_SYNCIO_HTTP *) p;
 
   GWEN_DB_Group_free(xio->dbCommandOut);
   GWEN_DB_Group_free(xio->dbStatusOut);
@@ -94,7 +96,8 @@ void GWENHYWFAR_CB GWEN_SyncIo_Http_FreeData(void *bp, void *p) {
 
 
 
-int GWENHYWFAR_CB GWEN_SyncIo_Http_Connect(GWEN_SYNCIO *sio) {
+int GWENHYWFAR_CB GWEN_SyncIo_Http_Connect(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -125,7 +128,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Connect(GWEN_SYNCIO *sio) {
 
 
 
-int GWENHYWFAR_CB GWEN_SyncIo_Http_Disconnect(GWEN_SYNCIO *sio) {
+int GWENHYWFAR_CB GWEN_SyncIo_Http_Disconnect(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -154,7 +158,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Disconnect(GWEN_SYNCIO *sio) {
 
 
 
-void GWEN_SyncIo_Http_SetReadIdle(GWEN_SYNCIO *sio) {
+void GWEN_SyncIo_Http_SetReadIdle(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -167,8 +172,9 @@ void GWEN_SyncIo_Http_SetReadIdle(GWEN_SYNCIO *sio) {
 
 
 int GWENHYWFAR_CB GWEN_SyncIo_Http_Read(GWEN_SYNCIO *sio,
-					uint8_t *buffer,
-					uint32_t size) {
+                                        uint8_t *buffer,
+                                        uint32_t size)
+{
   GWEN_SYNCIO_HTTP *xio;
   int rv;
 
@@ -194,19 +200,19 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Read(GWEN_SYNCIO *sio,
       rv=GWEN_SyncIo_Http_ReadCommand(sio);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	xio->readMode=GWEN_SyncIo_Http_Mode_Error;
-	return rv;
+        xio->readMode=GWEN_SyncIo_Http_Mode_Error;
+        return rv;
       }
 
       /* possibly read header */
       s=GWEN_DB_GetCharValue(xio->dbCommandIn, "protocol", 0, "HTTP/1.0");
       if (!(s && strcasecmp(s, "HTTP/0.9")==0)) {
-	rv=GWEN_SyncIo_Http_ReadHeader(sio);
-	if (rv<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	  xio->readMode=GWEN_SyncIo_Http_Mode_Error;
-	  return rv;
-	}
+        rv=GWEN_SyncIo_Http_ReadHeader(sio);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          xio->readMode=GWEN_SyncIo_Http_Mode_Error;
+          return rv;
+        }
       }
     }
     else {
@@ -214,19 +220,19 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Read(GWEN_SYNCIO *sio,
       rv=GWEN_SyncIo_Http_ReadStatus(sio);
       if (rv<0) {
         DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	xio->readMode=GWEN_SyncIo_Http_Mode_Error;
-	return rv;
+        xio->readMode=GWEN_SyncIo_Http_Mode_Error;
+        return rv;
       }
 
       /* possibly read header */
       s=GWEN_DB_GetCharValue(xio->dbStatusIn, "protocol", 0, "HTTP/1.0");
       if (!(s && strcasecmp(s, "HTTP/0.9")==0)) {
-	rv=GWEN_SyncIo_Http_ReadHeader(sio);
-	if (rv<0) {
-	  DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	  xio->readMode=GWEN_SyncIo_Http_Mode_Error;
-	  return rv;
-	}
+        rv=GWEN_SyncIo_Http_ReadHeader(sio);
+        if (rv<0) {
+          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+          xio->readMode=GWEN_SyncIo_Http_Mode_Error;
+          return rv;
+        }
       }
     }
 
@@ -304,8 +310,9 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Read(GWEN_SYNCIO *sio,
 
 
 int GWENHYWFAR_CB GWEN_SyncIo_Http_Write(GWEN_SYNCIO *sio,
-					 const uint8_t *buffer,
-					 uint32_t size) {
+                                         const uint8_t *buffer,
+                                         uint32_t size)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -341,8 +348,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Write(GWEN_SYNCIO *sio,
     if (!(s && strcasecmp(s, "HTTP/0.9")==0)) {
       rv=GWEN_SyncIo_Http_WriteHeader(sio);
       if (rv<0) {
-	xio->writeMode=GWEN_SyncIo_Http_Mode_Error;
-	return rv;
+        xio->writeMode=GWEN_SyncIo_Http_Mode_Error;
+        return rv;
       }
     }
   }
@@ -378,7 +385,7 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Write(GWEN_SYNCIO *sio,
 
   if (xio->writeMode==GWEN_SyncIo_Http_Mode_Body) {
     if ((xio->currentWriteBodySize!=-1) &&
-	(size>xio->currentWriteBodySize)) {
+        ((int)size>xio->currentWriteBodySize)) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Size is beyond total body size (%d)!", size);
       xio->writeMode=GWEN_SyncIo_Http_Mode_Error;
       return GWEN_ERROR_INVALID;
@@ -394,7 +401,7 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Write(GWEN_SYNCIO *sio,
     if (xio->currentWriteBodySize!=-1) {
       xio->currentWriteBodySize-=rv;
       if (xio->currentWriteBodySize==0)
-	GWEN_SyncIo_Http_SetWriteIdle(sio);
+        GWEN_SyncIo_Http_SetWriteIdle(sio);
     }
 
     return rv;
@@ -410,7 +417,8 @@ int GWENHYWFAR_CB GWEN_SyncIo_Http_Write(GWEN_SYNCIO *sio,
 
 
 
-int GWEN_SyncIo_Http_ReadLine(GWEN_SYNCIO *sio, GWEN_BUFFER *tbuf) {
+int GWEN_SyncIo_Http_ReadLine(GWEN_SYNCIO *sio, GWEN_BUFFER *tbuf)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -431,7 +439,7 @@ int GWEN_SyncIo_Http_ReadLine(GWEN_SYNCIO *sio, GWEN_BUFFER *tbuf) {
     uint32_t l;
 
     GWEN_Buffer_AllocRoom(tbuf, 1024);
-    p=(uint8_t*) GWEN_Buffer_GetPosPointer(tbuf);
+    p=(uint8_t *) GWEN_Buffer_GetPosPointer(tbuf);
     l=GWEN_Buffer_GetMaxUnsegmentedWrite(tbuf);
     rv=GWEN_SyncIo_Read(baseIo, p, l);
     if (rv<0) {
@@ -443,12 +451,13 @@ int GWEN_SyncIo_Http_ReadLine(GWEN_SYNCIO *sio, GWEN_BUFFER *tbuf) {
       GWEN_Buffer_AdjustUsedBytes(tbuf);
       if (p[rv-1]==10) {
         p[rv-1]=0;
-	break;
+        break;
       }
     }
     else if (rv==0)
       break;
-  } while(rv>0);
+  }
+  while (rv>0);
 
   if (GWEN_Buffer_GetUsedBytes(tbuf)<1) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Nothing received");
@@ -460,7 +469,8 @@ int GWEN_SyncIo_Http_ReadLine(GWEN_SYNCIO *sio, GWEN_BUFFER *tbuf) {
 
 
 
-int GWEN_SyncIo_Http_ParseStatus(GWEN_SYNCIO *sio, char *buffer) {
+int GWEN_SyncIo_Http_ParseStatus(GWEN_SYNCIO *sio, char *buffer)
+{
   GWEN_SYNCIO_HTTP *xio;
   char *p;
   char *s;
@@ -486,7 +496,7 @@ int GWEN_SyncIo_Http_ParseStatus(GWEN_SYNCIO *sio, char *buffer) {
   s=p;
 
   /* read status code */
-  while(*p && isdigit((int)*p))
+  while (*p && isdigit((int)*p))
     p++;
   if (*p) {
     *p=0;
@@ -507,7 +517,8 @@ int GWEN_SyncIo_Http_ParseStatus(GWEN_SYNCIO *sio, char *buffer) {
 
 
 
-int GWEN_SyncIo_Http_ParseCommand(GWEN_SYNCIO *sio, const char *buffer) {
+int GWEN_SyncIo_Http_ParseCommand(GWEN_SYNCIO *sio, const char *buffer)
+{
   GWEN_SYNCIO_HTTP *xio;
   char *tmp;
   char *p;
@@ -537,10 +548,10 @@ int GWEN_SyncIo_Http_ParseCommand(GWEN_SYNCIO *sio, const char *buffer) {
   /* read URL */
   p=strchr(s, ' ');
   if (!p) {
-      DBG_ERROR(GWEN_LOGDOMAIN,
-		"Bad format of HTTP request (%s)", buffer);
-      free(tmp);
-      return GWEN_ERROR_INVALID;
+    DBG_ERROR(GWEN_LOGDOMAIN,
+              "Bad format of HTTP request (%s)", buffer);
+    free(tmp);
+    return GWEN_ERROR_INVALID;
   }
   *p=0;
   p++;
@@ -564,7 +575,8 @@ int GWEN_SyncIo_Http_ParseCommand(GWEN_SYNCIO *sio, const char *buffer) {
 
 
 
-int GWEN_SyncIo_Http_ReadStatus(GWEN_SYNCIO *sio) {
+int GWEN_SyncIo_Http_ReadStatus(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   GWEN_BUFFER *tbuf;
@@ -593,6 +605,14 @@ int GWEN_SyncIo_Http_ReadStatus(GWEN_SYNCIO *sio) {
     return GWEN_ERROR_EOF;
   }
 
+  if (GWEN_Logger_GetLevel(GWEN_LOGDOMAIN)>=GWEN_LoggerLevel_Debug) {
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Received HTTP status:");
+    GWEN_Text_LogString((const char *) GWEN_Buffer_GetStart(tbuf),
+                        GWEN_Buffer_GetUsedBytes(tbuf),
+                        GWEN_LOGDOMAIN,
+                        GWEN_LoggerLevel_Debug);
+  }
+
   rv=GWEN_SyncIo_Http_ParseStatus(sio, GWEN_Buffer_GetStart(tbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -606,7 +626,8 @@ int GWEN_SyncIo_Http_ReadStatus(GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_ReadCommand(GWEN_SYNCIO *sio) {
+int GWEN_SyncIo_Http_ReadCommand(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   GWEN_BUFFER *tbuf;
@@ -642,7 +663,8 @@ int GWEN_SyncIo_Http_ReadCommand(GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_ParseHeader(GWEN_SYNCIO *sio, char *buf) {
+int GWEN_SyncIo_Http_ParseHeader(GWEN_SYNCIO *sio, char *buf)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   char *p;
@@ -657,19 +679,19 @@ int GWEN_SyncIo_Http_ParseHeader(GWEN_SYNCIO *sio, char *buf) {
 
   /* resolve line continuations */
   p=buf;
-  while(*p) {
+  while (*p) {
     p=strchr(p, 10);
     if (p) {
       if (p[1]==32 || p[1]==9)
-	/* found a continuation */
-	*p=32;
+        /* found a continuation */
+        *p=32;
       p++;
     }
   }
 
   /* parse every line */
   p=buf;
-  while(p && *p) {
+  while (p && *p) {
     char *pNext;
     char *pVarBegin;
     char *pVarEnd;
@@ -680,24 +702,24 @@ int GWEN_SyncIo_Http_ParseHeader(GWEN_SYNCIO *sio, char *buf) {
       *pNext=0;
       pNext++;
     }
-    while(*p && (*p==32 || *p==9))
+    while (*p && (*p==32 || *p==9))
       p++;
     if (*p) {
       pVarBegin=p;
-      while(*p && *p!=':' && *p>32 && *p<127)
-	p++;
+      while (*p && *p!=':' && *p>32 && *p<127)
+        p++;
       pVarEnd=p;
       if (*p!=':') {
-	DBG_INFO(GWEN_LOGDOMAIN, "No separator after variable name in received header");
-	return GWEN_ERROR_BAD_DATA;
+        DBG_INFO(GWEN_LOGDOMAIN, "No separator after variable name in received header");
+        return GWEN_ERROR_BAD_DATA;
       }
       *pVarEnd=0;
       p++;
 
-      while(*p && (*p==32 || *p==9))
-	p++;
+      while (*p && (*p==32 || *p==9))
+        p++;
       if (*p)
-	GWEN_DB_SetCharValue(xio->dbHeaderIn, GWEN_PATH_FLAGS_CREATE_VAR, pVarBegin, p);
+        GWEN_DB_SetCharValue(xio->dbHeaderIn, GWEN_PATH_FLAGS_CREATE_VAR, pVarBegin, p);
     }
     p=pNext;
   }
@@ -740,7 +762,8 @@ int GWEN_SyncIo_Http_ParseHeader(GWEN_SYNCIO *sio, char *buf) {
 
 
 
-int GWEN_SyncIo_Http_ReadHeader(GWEN_SYNCIO *sio) {
+int GWEN_SyncIo_Http_ReadHeader(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   GWEN_BUFFER *tbuf;
@@ -766,7 +789,7 @@ int GWEN_SyncIo_Http_ReadHeader(GWEN_SYNCIO *sio) {
     uint8_t *p;
 
     GWEN_Buffer_AllocRoom(tbuf, 1024);
-    p=(uint8_t*) GWEN_Buffer_GetPosPointer(tbuf);
+    p=(uint8_t *) GWEN_Buffer_GetPosPointer(tbuf);
     rv=GWEN_SyncIo_Read(baseIo, p, 1024);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -777,20 +800,21 @@ int GWEN_SyncIo_Http_ReadHeader(GWEN_SYNCIO *sio) {
       GWEN_Buffer_IncrementPos(tbuf, rv);
       GWEN_Buffer_AdjustUsedBytes(tbuf);
       if (p[rv-1]==10) {
-	uint32_t npos;
+        uint32_t npos;
 
         lines++;
-	npos=GWEN_Buffer_GetPos(tbuf);
-	if ((npos-pos)==1) {
-	  /* empty line, header finished */
-	  break;
-	}
+        npos=GWEN_Buffer_GetPos(tbuf);
+        if ((npos-pos)==1) {
+          /* empty line, header finished */
+          break;
+        }
         pos=npos;
       }
     }
     else if (rv==0)
       break;
-  } while(rv>0);
+  }
+  while (rv>0);
 
   if (lines<1) {
     DBG_ERROR(GWEN_LOGDOMAIN, "No header line received");
@@ -798,6 +822,14 @@ int GWEN_SyncIo_Http_ReadHeader(GWEN_SYNCIO *sio) {
     return GWEN_ERROR_EOF;
   }
 
+  if (GWEN_Logger_GetLevel(GWEN_LOGDOMAIN)>=GWEN_LoggerLevel_Debug) {
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Received HTTP header:");
+    GWEN_Text_LogString((const char *) GWEN_Buffer_GetStart(tbuf),
+                        GWEN_Buffer_GetUsedBytes(tbuf),
+                        GWEN_LOGDOMAIN,
+                        GWEN_LoggerLevel_Debug);
+  }
+
   rv=GWEN_SyncIo_Http_ParseHeader(sio, GWEN_Buffer_GetStart(tbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
@@ -811,7 +843,8 @@ int GWEN_SyncIo_Http_ReadHeader(GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_ReadChunkSize(GWEN_SYNCIO *sio) {
+int GWEN_SyncIo_Http_ReadChunkSize(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   GWEN_BUFFER *tbuf;
@@ -860,7 +893,8 @@ int GWEN_SyncIo_Http_ReadChunkSize(GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_ReadChunk(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size) {
+int GWEN_SyncIo_Http_ReadChunk(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -876,7 +910,7 @@ int GWEN_SyncIo_Http_ReadChunk(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size)
   /* we want to read binary data transparently */
   GWEN_SyncIo_AddFlags(baseIo, GWEN_SYNCIO_FLAGS_TRANSPARENT);
 
-  if (size>xio->currentReadChunkSize)
+  if ((int)size>xio->currentReadChunkSize)
     size=xio->currentReadChunkSize;
 
   rv=GWEN_SyncIo_Read(baseIo, buffer, size);
@@ -914,7 +948,8 @@ int GWEN_SyncIo_Http_ReadChunk(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size)
 
 
 
-int GWEN_SyncIo_Http_ReadBody(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size) {
+int GWEN_SyncIo_Http_ReadBody(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -933,9 +968,9 @@ int GWEN_SyncIo_Http_ReadBody(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size)
   GWEN_SyncIo_AddFlags(baseIo, GWEN_SYNCIO_FLAGS_TRANSPARENT);
 
   if ((xio->currentReadBodySize>=0) &&
-      (size>xio->currentReadBodySize)) {
+      ((int)size>xio->currentReadBodySize)) {
     DBG_INFO(GWEN_LOGDOMAIN, "Adjusting read body size from %d to %d",
-	     size, xio->currentReadBodySize);
+             size, xio->currentReadBodySize);
     size=xio->currentReadBodySize;
   }
 
@@ -957,7 +992,8 @@ int GWEN_SyncIo_Http_ReadBody(GWEN_SYNCIO *sio, uint8_t *buffer, uint32_t size)
 
 
 
-int GWEN_SyncIo_Http_WriteCommand(GWEN_SYNCIO *sio) {
+int GWEN_SyncIo_Http_WriteCommand(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -988,10 +1024,18 @@ int GWEN_SyncIo_Http_WriteCommand(GWEN_SYNCIO *sio) {
   GWEN_Buffer_AppendString(tbuf, s);
   GWEN_Buffer_AppendString(tbuf, "\r\n");
 
+  if (GWEN_Logger_GetLevel(GWEN_LOGDOMAIN)>=GWEN_LoggerLevel_Debug) {
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Sending HTTP command:");
+    GWEN_Text_LogString((const char *) GWEN_Buffer_GetStart(tbuf),
+                        GWEN_Buffer_GetUsedBytes(tbuf),
+                        GWEN_LOGDOMAIN,
+                        GWEN_LoggerLevel_Debug);
+  }
+
   /* write */
   rv=GWEN_SyncIo_WriteForced(baseIo,
-			     (const uint8_t*) GWEN_Buffer_GetStart(tbuf),
-			     GWEN_Buffer_GetUsedBytes(tbuf));
+                             (const uint8_t *) GWEN_Buffer_GetStart(tbuf),
+                             GWEN_Buffer_GetUsedBytes(tbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_free(tbuf);
@@ -1004,7 +1048,8 @@ int GWEN_SyncIo_Http_WriteCommand(GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_WriteStatus(GWEN_SYNCIO *sio) {
+int GWEN_SyncIo_Http_WriteStatus(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -1044,8 +1089,8 @@ int GWEN_SyncIo_Http_WriteStatus(GWEN_SYNCIO *sio) {
 
   /* write */
   rv=GWEN_SyncIo_WriteForced(baseIo,
-			     (const uint8_t*) GWEN_Buffer_GetStart(tbuf),
-			     GWEN_Buffer_GetUsedBytes(tbuf));
+                             (const uint8_t *) GWEN_Buffer_GetStart(tbuf),
+                             GWEN_Buffer_GetUsedBytes(tbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_free(tbuf);
@@ -1058,7 +1103,8 @@ int GWEN_SyncIo_Http_WriteStatus(GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_WriteHeader(GWEN_SYNCIO *sio) {
+int GWEN_SyncIo_Http_WriteHeader(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int i;
@@ -1096,39 +1142,39 @@ int GWEN_SyncIo_Http_WriteHeader(GWEN_SYNCIO *sio) {
 
       vtype=GWEN_DB_GetValueType(dbVal);
       if (vtype==GWEN_DB_NodeType_ValueChar) {
-	const char *s;
+        const char *s;
 
-	GWEN_Buffer_AppendString(tbuf, GWEN_DB_VariableName(dbVar));
-	GWEN_Buffer_AppendString(tbuf, ":");
-	s=GWEN_DB_GetCharValueFromNode(dbVal);
+        GWEN_Buffer_AppendString(tbuf, GWEN_DB_VariableName(dbVar));
+        GWEN_Buffer_AppendString(tbuf, ":");
+        s=GWEN_DB_GetCharValueFromNode(dbVal);
         if (s)
-	  GWEN_Buffer_AppendString(tbuf, s);
-	GWEN_Buffer_AppendString(tbuf, "\r\n");
+          GWEN_Buffer_AppendString(tbuf, s);
+        GWEN_Buffer_AppendString(tbuf, "\r\n");
 
-	if (strcasecmp(GWEN_DB_VariableName(dbVar), "Transfer-Encoding")==0) {
-	  if (s && (-1!=GWEN_Text_ComparePattern(s, "*chunked*", 0))) {
-	    /* chunked encoding, this means next we have to write the chunksize */
-	    xio->writeMode=GWEN_SyncIo_Http_Mode_ChunkSize;
-	  }
-	}
+        if (strcasecmp(GWEN_DB_VariableName(dbVar), "Transfer-Encoding")==0) {
+          if (s && (-1!=GWEN_Text_ComparePattern(s, "*chunked*", 0))) {
+            /* chunked encoding, this means next we have to write the chunksize */
+            xio->writeMode=GWEN_SyncIo_Http_Mode_ChunkSize;
+          }
+        }
       }
       else if (vtype==GWEN_DB_NodeType_ValueInt) {
-	i=GWEN_DB_GetIntValueFromNode(dbVal);
-	if (i!=-1 || strcasecmp(GWEN_DB_VariableName(dbVar), "Content-Length")==0) {
-	  char numbuf[32];
+        i=GWEN_DB_GetIntValueFromNode(dbVal);
+        if (i!=-1 || strcasecmp(GWEN_DB_VariableName(dbVar), "Content-Length")==0) {
+          char numbuf[32];
 
-	  /* don't write body size of -1 */
-	  GWEN_Buffer_AppendString(tbuf, GWEN_DB_VariableName(dbVar));
-	  GWEN_Buffer_AppendString(tbuf, ":");
-	  snprintf(numbuf, sizeof(numbuf), "%d", i);
-	  GWEN_Buffer_AppendString(tbuf, numbuf);
-	  GWEN_Buffer_AppendString(tbuf, "\r\n");
-	}
+          /* don't write body size of -1 */
+          GWEN_Buffer_AppendString(tbuf, GWEN_DB_VariableName(dbVar));
+          GWEN_Buffer_AppendString(tbuf, ":");
+          snprintf(numbuf, sizeof(numbuf), "%d", i);
+          GWEN_Buffer_AppendString(tbuf, numbuf);
+          GWEN_Buffer_AppendString(tbuf, "\r\n");
+        }
       }
       else {
-	DBG_INFO(GWEN_LOGDOMAIN, "Variable type %d of var [%s] not supported",
-		 vtype, GWEN_DB_VariableName(dbVar));
-	return GWEN_ERROR_BAD_DATA;
+        DBG_INFO(GWEN_LOGDOMAIN, "Variable type %d of var [%s] not supported",
+                 vtype, GWEN_DB_VariableName(dbVar));
+        return GWEN_ERROR_BAD_DATA;
       }
     }
     dbVar=GWEN_DB_GetNextVar(dbVar);
@@ -1137,10 +1183,18 @@ int GWEN_SyncIo_Http_WriteHeader(GWEN_SYNCIO *sio) {
   /* finalize header */
   GWEN_Buffer_AppendString(tbuf, "\r\n");
 
+  if (GWEN_Logger_GetLevel(GWEN_LOGDOMAIN)>=GWEN_LoggerLevel_Debug) {
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Sending HTTP header:");
+    GWEN_Text_LogString((const char *) GWEN_Buffer_GetStart(tbuf),
+                        GWEN_Buffer_GetUsedBytes(tbuf),
+                        GWEN_LOGDOMAIN,
+                        GWEN_LoggerLevel_Debug);
+  }
+
   /* write */
   rv=GWEN_SyncIo_WriteForced(baseIo,
-			     (const uint8_t*) GWEN_Buffer_GetStart(tbuf),
-			     GWEN_Buffer_GetUsedBytes(tbuf));
+                             (const uint8_t *) GWEN_Buffer_GetStart(tbuf),
+                             GWEN_Buffer_GetUsedBytes(tbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_Buffer_free(tbuf);
@@ -1156,7 +1210,8 @@ int GWEN_SyncIo_Http_WriteHeader(GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_WriteChunkSize(GWEN_SYNCIO *sio, uint32_t size) {
+int GWEN_SyncIo_Http_WriteChunkSize(GWEN_SYNCIO *sio, uint32_t size)
+{
   GWEN_SYNCIO_HTTP *xio;
   GWEN_SYNCIO *baseIo;
   int rv;
@@ -1175,7 +1230,7 @@ int GWEN_SyncIo_Http_WriteChunkSize(GWEN_SYNCIO *sio, uint32_t size) {
   snprintf(numbuf, sizeof(numbuf)-1, "%x\r\n", size);
   numbuf[sizeof(numbuf)-1]=0;
 
-  rv=GWEN_SyncIo_WriteForced(baseIo, (const uint8_t*) numbuf, strlen(numbuf));
+  rv=GWEN_SyncIo_WriteForced(baseIo, (const uint8_t *) numbuf, strlen(numbuf));
   if (rv<0) {
     DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     return rv;
@@ -1186,7 +1241,8 @@ int GWEN_SyncIo_Http_WriteChunkSize(GWEN_SYNCIO *sio, uint32_t size) {
 
 
 
-void GWEN_SyncIo_Http_SetWriteIdle(GWEN_SYNCIO *sio) {
+void GWEN_SyncIo_Http_SetWriteIdle(GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -1200,7 +1256,8 @@ void GWEN_SyncIo_Http_SetWriteIdle(GWEN_SYNCIO *sio) {
 
 
 
-GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbCommandIn(const GWEN_SYNCIO *sio) {
+GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbCommandIn(const GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -1212,7 +1269,8 @@ GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbCommandIn(const GWEN_SYNCIO *sio) {
 
 
 
-GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbStatusIn(const GWEN_SYNCIO *sio) {
+GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbStatusIn(const GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -1224,7 +1282,8 @@ GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbStatusIn(const GWEN_SYNCIO *sio) {
 
 
 
-GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbHeaderIn(const GWEN_SYNCIO *sio) {
+GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbHeaderIn(const GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -1236,7 +1295,8 @@ GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbHeaderIn(const GWEN_SYNCIO *sio) {
 
 
 
-GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbCommandOut(const GWEN_SYNCIO *sio) {
+GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbCommandOut(const GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -1248,7 +1308,8 @@ GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbCommandOut(const GWEN_SYNCIO *sio) {
 
 
 
-GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbStatusOut(const GWEN_SYNCIO *sio) {
+GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbStatusOut(const GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -1260,7 +1321,8 @@ GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbStatusOut(const GWEN_SYNCIO *sio) {
 
 
 
-GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbHeaderOut(const GWEN_SYNCIO *sio) {
+GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbHeaderOut(const GWEN_SYNCIO *sio)
+{
   GWEN_SYNCIO_HTTP *xio;
 
   assert(sio);
@@ -1273,9 +1335,10 @@ GWEN_DB_NODE *GWEN_SyncIo_Http_GetDbHeaderOut(const GWEN_SYNCIO *sio) {
 
 
 
-int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
+int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf)
+{
   GWEN_SYNCIO_HTTP *xio;
-  int rv;
+  int rv=0;
   int code=0;
   int firstRead=1;
   int bodySize=-1;
@@ -1308,27 +1371,28 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
       return rv;
     }
 
-    p=(uint8_t*) GWEN_Buffer_GetPosPointer(buf);
+    p=(uint8_t *) GWEN_Buffer_GetPosPointer(buf);
     l=GWEN_Buffer_GetMaxUnsegmentedWrite(buf);
     do {
       rv=GWEN_SyncIo_Read(sio, p, l-1);
-    } while(rv==GWEN_ERROR_INTERRUPTED);
+    }
+    while (rv==GWEN_ERROR_INTERRUPTED);
 
-    if (rv==0)
+    if (rv==0) /* EOF met */
       break;
     else if (rv<0) {
       if (rv==GWEN_ERROR_EOF) {
-	if (bodySize!=-1 && bytesRead<bodySize) {
-	    DBG_ERROR(GWEN_LOGDOMAIN,
-		      "EOF met prematurely (%d < %d)",
-		      bytesRead, bodySize);
-            GWEN_Gui_ProgressEnd(pid);
-	    return GWEN_ERROR_EOF;
-	}
+        if (bodySize!=-1 && bytesRead<bodySize) {
+          DBG_ERROR(GWEN_LOGDOMAIN,
+                    "EOF met prematurely (%d < %d)",
+                    bytesRead, bodySize);
+          GWEN_Gui_ProgressEnd(pid);
+          return GWEN_ERROR_EOF;
+        }
       }
       else {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	/*return rv;*/
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        /*return rv;*/
         break;
       }
     }
@@ -1336,13 +1400,13 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
       GWEN_Buffer_IncrementPos(buf, rv);
       GWEN_Buffer_AdjustUsedBytes(buf);
       if (firstRead) {
-	GWEN_DB_NODE *db;
+        GWEN_DB_NODE *db;
 
-	db=GWEN_SyncIo_Http_GetDbHeaderIn(sio);
-	bodySize=GWEN_DB_GetIntValue(db, "Content-length", 0, -1);
+        db=GWEN_SyncIo_Http_GetDbHeaderIn(sio);
+        bodySize=GWEN_DB_GetIntValue(db, "Content-length", 0, -1);
 
-	if (bodySize!=-1)
-	  GWEN_Gui_ProgressSetTotal(pid, bodySize);
+        if (bodySize!=-1)
+          GWEN_Gui_ProgressSetTotal(pid, bodySize);
       }
       bytesRead+=rv;
 
@@ -1367,23 +1431,23 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
     if (GWEN_Buffer_GetUsedBytes(buf)) {
       /* data received, check for common error codes */
       if (rv==GWEN_ERROR_EOF || rv==GWEN_ERROR_IO || rv==GWEN_ERROR_SSL) {
-	DBG_INFO(GWEN_LOGDOMAIN,
-		 "We received an error, but we still got data, "
-		 "so we ignore the error here");
+        DBG_INFO(GWEN_LOGDOMAIN,
+                 "We received an error, but we still got data, "
+                 "so we ignore the error here");
       }
       else {
-	DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
-	GWEN_Gui_ProgressLog(0,
-			     GWEN_LoggerLevel_Error,
-			     I18N("No message received"));
-	return rv;
+        DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
+        GWEN_Gui_ProgressLog(0,
+                             GWEN_LoggerLevel_Error,
+                             I18N("No message received"));
+        return rv;
       }
     }
     else {
       DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
       GWEN_Gui_ProgressLog(0,
-			   GWEN_LoggerLevel_Error,
-			   I18N("No message received"));
+                           GWEN_LoggerLevel_Error,
+                           I18N("No message received"));
       return rv;
     }
   }
@@ -1397,16 +1461,16 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
 
       s=GWEN_DB_GetCharValue(xio->dbStatusIn, "text", 0, NULL);
       DBG_DEBUG(GWEN_LOGDOMAIN, "HTTP-Status: %d (%s)",
-		code, s?s:"- no text -");
-      GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Info,
-			    I18N("HTTP-Status: %d (%s)"),
-			    code, s?s:I18N("- no details -)"));
+                code, s?s:"- no text -");
+      GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Debug,
+                            I18N("HTTP-Status: %d (%s)"),
+                            code, s?s:I18N("- no details -"));
     }
     else {
       DBG_ERROR(GWEN_LOGDOMAIN, "No HTTP status code received");
       GWEN_Gui_ProgressLog(0,
-			   GWEN_LoggerLevel_Error,
-			   I18N("No HTTP status code received"));
+                           GWEN_LoggerLevel_Error,
+                           I18N("No HTTP status code received"));
       code=GWEN_ERROR_BAD_DATA;
     }
   }
@@ -1416,7 +1480,8 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
 
 
 
-int GWEN_SyncIo_Http_RecvBodyToSio(GWEN_SYNCIO *sio, GWEN_SYNCIO *sout) {
+int GWEN_SyncIo_Http_RecvBodyToSio(GWEN_SYNCIO *sio, GWEN_SYNCIO *sout)
+{
   GWEN_SYNCIO_HTTP *xio;
   int rv;
   int code=0;
@@ -1449,23 +1514,24 @@ int GWEN_SyncIo_Http_RecvBodyToSio(GWEN_SYNCIO *sio, GWEN_SYNCIO *sout) {
 
     do {
       rv=GWEN_SyncIo_Read(sio, p, l-1);
-    } while(rv==GWEN_ERROR_INTERRUPTED);
+    }
+    while (rv==GWEN_ERROR_INTERRUPTED);
 
     if (rv==0)
       break;
     else if (rv<0) {
       if (rv==GWEN_ERROR_EOF) {
-	if (bodySize!=-1 && bytesRead<bodySize) {
-	    DBG_ERROR(GWEN_LOGDOMAIN,
-		      "EOF met prematurely (%d < %d)",
-		      bytesRead, bodySize);
-            GWEN_Gui_ProgressEnd(pid);
-	    return GWEN_ERROR_EOF;
-	}
+        if (bodySize!=-1 && bytesRead<bodySize) {
+          DBG_ERROR(GWEN_LOGDOMAIN,
+                    "EOF met prematurely (%d < %d)",
+                    bytesRead, bodySize);
+          GWEN_Gui_ProgressEnd(pid);
+          return GWEN_ERROR_EOF;
+        }
       }
       else {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
-	/*return rv;*/
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        /*return rv;*/
         break;
       }
     }
@@ -1474,18 +1540,18 @@ int GWEN_SyncIo_Http_RecvBodyToSio(GWEN_SYNCIO *sio, GWEN_SYNCIO *sout) {
 
       rv2=GWEN_SyncIo_WriteForced(sout, rbuf, rv);
       if (rv2<0) {
-	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv2);
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv2);
         GWEN_Gui_ProgressEnd(pid);
-	return rv2;
+        return rv2;
       }
       if (firstRead) {
-	GWEN_DB_NODE *db;
+        GWEN_DB_NODE *db;
 
-	db=GWEN_SyncIo_Http_GetDbHeaderIn(sio);
-	bodySize=GWEN_DB_GetIntValue(db, "Content-length", 0, -1);
+        db=GWEN_SyncIo_Http_GetDbHeaderIn(sio);
+        bodySize=GWEN_DB_GetIntValue(db, "Content-length", 0, -1);
 
-	if (bodySize!=-1)
-	  GWEN_Gui_ProgressSetTotal(pid, bodySize);
+        if (bodySize!=-1)
+          GWEN_Gui_ProgressSetTotal(pid, bodySize);
       }
       bytesRead+=rv;
 
@@ -1510,23 +1576,23 @@ int GWEN_SyncIo_Http_RecvBodyToSio(GWEN_SYNCIO *sio, GWEN_SYNCIO *sout) {
     if (bytesRead) {
       /* data received, check for common error codes */
       if (rv==GWEN_ERROR_EOF || rv==GWEN_ERROR_IO || rv==GWEN_ERROR_SSL) {
-	DBG_INFO(GWEN_LOGDOMAIN,
-		 "We received an error, but we still got data, "
-		 "so we ignore the error here");
+        DBG_INFO(GWEN_LOGDOMAIN,
+                 "We received an error, but we still got data, "
+                 "so we ignore the error here");
       }
       else {
-	DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
-	GWEN_Gui_ProgressLog(0,
-			     GWEN_LoggerLevel_Error,
-			     I18N("No message received"));
-	return rv;
+        DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
+        GWEN_Gui_ProgressLog(0,
+                             GWEN_LoggerLevel_Error,
+                             I18N("No message received"));
+        return rv;
       }
     }
     else {
       DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
       GWEN_Gui_ProgressLog(0,
-			   GWEN_LoggerLevel_Error,
-			   I18N("No message received"));
+                           GWEN_LoggerLevel_Error,
+                           I18N("No message received"));
       return rv;
     }
   }
@@ -1540,16 +1606,16 @@ int GWEN_SyncIo_Http_RecvBodyToSio(GWEN_SYNCIO *sio, GWEN_SYNCIO *sout) {
 
       s=GWEN_DB_GetCharValue(xio->dbStatusIn, "text", 0, NULL);
       DBG_DEBUG(GWEN_LOGDOMAIN, "HTTP-Status: %d (%s)",
-		code, s?s:"- no text -");
-      GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Info,
-			    I18N("HTTP-Status: %d (%s)"),
-			    code, s?s:I18N("- no details -)"));
+                code, s?s:"- no text -");
+      GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Debug,
+                            I18N("HTTP-Status: %d (%s)"),
+                            code, s?s:I18N("- no details -)"));
     }
     else {
       DBG_ERROR(GWEN_LOGDOMAIN, "No HTTP status code received");
       GWEN_Gui_ProgressLog(0,
-			   GWEN_LoggerLevel_Error,
-			   I18N("No HTTP status code received"));
+                           GWEN_LoggerLevel_Error,
+                           I18N("No HTTP status code received"));
       code=GWEN_ERROR_BAD_DATA;
     }
   }
